# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.cluster.configuration import Configuration


class CodegenNode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_name': 'str',
        'status': 'str',
        'resources': 'dict(str, str)',
        'labels': 'dict(str, str)',
        'annotations': 'dict(str, str)',
        'resource_usage': 'dict(str, float)'
    }

    attribute_map = {
        'node_name': 'nodeName',
        'status': 'status',
        'resources': 'resources',
        'labels': 'labels',
        'annotations': 'annotations',
        'resource_usage': 'resourceUsage'
    }

    def __init__(self, node_name=None, status=None, resources=None, labels=None, annotations=None, resource_usage=None, local_vars_configuration=None):  # noqa: E501
        """CodegenNode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_name = None
        self._status = None
        self._resources = None
        self._labels = None
        self._annotations = None
        self._resource_usage = None
        self.discriminator = None

        if node_name is not None:
            self.node_name = node_name
        if status is not None:
            self.status = status
        if resources is not None:
            self.resources = resources
        if labels is not None:
            self.labels = labels
        if annotations is not None:
            self.annotations = annotations
        if resource_usage is not None:
            self.resource_usage = resource_usage

    @property
    def node_name(self):
        """Gets the node_name of this CodegenNode.  # noqa: E501


        :return: The node_name of this CodegenNode.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this CodegenNode.


        :param node_name: The node_name of this CodegenNode.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def status(self):
        """Gets the status of this CodegenNode.  # noqa: E501


        :return: The status of this CodegenNode.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CodegenNode.


        :param status: The status of this CodegenNode.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def resources(self):
        """Gets the resources of this CodegenNode.  # noqa: E501


        :return: The resources of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this CodegenNode.


        :param resources: The resources of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._resources = resources

    @property
    def labels(self):
        """Gets the labels of this CodegenNode.  # noqa: E501


        :return: The labels of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this CodegenNode.


        :param labels: The labels of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def annotations(self):
        """Gets the annotations of this CodegenNode.  # noqa: E501


        :return: The annotations of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this CodegenNode.


        :param annotations: The annotations of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def resource_usage(self):
        """Gets the resource_usage of this CodegenNode.  # noqa: E501


        :return: The resource_usage of this CodegenNode.  # noqa: E501
        :rtype: dict(str, float)
        """
        return self._resource_usage

    @resource_usage.setter
    def resource_usage(self, resource_usage):
        """Sets the resource_usage of this CodegenNode.


        :param resource_usage: The resource_usage of this CodegenNode.  # noqa: E501
        :type: dict(str, float)
        """

        self._resource_usage = resource_usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenNode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenNode):
            return True

        return self.to_dict() != other.to_dict()



import os
import unittest

from kaistack.components.component_store import create_from_template

ARGO_SPEC_FILENAME = os.path.join(os.path.dirname(__file__), 'argo_component.yaml')


class ComponentStoreTest(unittest.TestCase):
    def setUp(self) -> None:
        os.environ["AUTH_DOMAIN"] = 'dev-kdiij5qn.auth0.com'
        os.environ["AUTH_CLIENT_SECRET"] = 'nx_qxMhX0N4fUs5cBvxCmFuKwU5t7Rop20dDONB_zMeFUs0Oke1u7_Ce-nNqicQK'
        os.environ["AUTH_CLIENT_ID"] = 'gwkHgc6x19rT2CcUzqac7z2NGcyWzxnD'

    def tearDown(self) -> None:
        pass

    def test_create_from_component(self):
        with open(ARGO_SPEC_FILENAME, 'r') as f:
            spec = f.read()
            component = create_from_template(spec)
            self.assertEqual("Git clone", component.name)
            self.assertEqual("Creates a shallow clone of the specified repo branch", component.description)
            self.assertEqual("alpine/git", component.image)



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.workflow.configuration import Configuration


class CodegenModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'version': 'str',
        'framework': 'str',
        'framework_version': 'str',
        'uri': 'str',
        'artifact_id': 'str',
        'created_at': 'datetime',
        'properties': 'dict(str, str)',
        'pipeline_id': 'str',
        'step_run_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'version': 'version',
        'framework': 'framework',
        'framework_version': 'frameworkVersion',
        'uri': 'uri',
        'artifact_id': 'artifactId',
        'created_at': 'createdAt',
        'properties': 'properties',
        'pipeline_id': 'pipelineId',
        'step_run_id': 'stepRunId'
    }

    def __init__(self, name=None, version=None, framework=None, framework_version=None, uri=None, artifact_id=None, created_at=None, properties=None, pipeline_id=None, step_run_id=None, local_vars_configuration=None):  # noqa: E501
        """CodegenModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._version = None
        self._framework = None
        self._framework_version = None
        self._uri = None
        self._artifact_id = None
        self._created_at = None
        self._properties = None
        self._pipeline_id = None
        self._step_run_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if framework is not None:
            self.framework = framework
        if framework_version is not None:
            self.framework_version = framework_version
        if uri is not None:
            self.uri = uri
        if artifact_id is not None:
            self.artifact_id = artifact_id
        if created_at is not None:
            self.created_at = created_at
        if properties is not None:
            self.properties = properties
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if step_run_id is not None:
            self.step_run_id = step_run_id

    @property
    def name(self):
        """Gets the name of this CodegenModel.  # noqa: E501


        :return: The name of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CodegenModel.


        :param name: The name of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def version(self):
        """Gets the version of this CodegenModel.  # noqa: E501


        :return: The version of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CodegenModel.


        :param version: The version of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def framework(self):
        """Gets the framework of this CodegenModel.  # noqa: E501


        :return: The framework of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._framework

    @framework.setter
    def framework(self, framework):
        """Sets the framework of this CodegenModel.


        :param framework: The framework of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._framework = framework

    @property
    def framework_version(self):
        """Gets the framework_version of this CodegenModel.  # noqa: E501


        :return: The framework_version of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._framework_version

    @framework_version.setter
    def framework_version(self, framework_version):
        """Sets the framework_version of this CodegenModel.


        :param framework_version: The framework_version of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._framework_version = framework_version

    @property
    def uri(self):
        """Gets the uri of this CodegenModel.  # noqa: E501


        :return: The uri of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this CodegenModel.


        :param uri: The uri of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def artifact_id(self):
        """Gets the artifact_id of this CodegenModel.  # noqa: E501


        :return: The artifact_id of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._artifact_id

    @artifact_id.setter
    def artifact_id(self, artifact_id):
        """Sets the artifact_id of this CodegenModel.


        :param artifact_id: The artifact_id of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._artifact_id = artifact_id

    @property
    def created_at(self):
        """Gets the created_at of this CodegenModel.  # noqa: E501


        :return: The created_at of this CodegenModel.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CodegenModel.


        :param created_at: The created_at of this CodegenModel.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def properties(self):
        """Gets the properties of this CodegenModel.  # noqa: E501


        :return: The properties of this CodegenModel.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CodegenModel.


        :param properties: The properties of this CodegenModel.  # noqa: E501
        :type: dict(str, str)
        """

        self._properties = properties

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this CodegenModel.  # noqa: E501


        :return: The pipeline_id of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this CodegenModel.


        :param pipeline_id: The pipeline_id of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._pipeline_id = pipeline_id

    @property
    def step_run_id(self):
        """Gets the step_run_id of this CodegenModel.  # noqa: E501


        :return: The step_run_id of this CodegenModel.  # noqa: E501
        :rtype: str
        """
        return self._step_run_id

    @step_run_id.setter
    def step_run_id(self, step_run_id):
        """Sets the step_run_id of this CodegenModel.


        :param step_run_id: The step_run_id of this CodegenModel.  # noqa: E501
        :type: str
        """

        self._step_run_id = step_run_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenModel):
            return True

        return self.to_dict() != other.to_dict()



import json
import os
import time

import click
from auth0.v3.authentication import GetToken

from kaistack.auth.exceptions import NoAuthContextException
from kaistack.config.context import load_context

_TOKEN_CACHE_FILE = '~/.kaistack/authtoken'


def load_from_cache():
    cache_file = os.path.expanduser(_TOKEN_CACHE_FILE)
    if os.path.exists(cache_file):
        with open(cache_file, 'r') as f:
            token = f.read()
            result = json.loads(token)
            expires_in = result['expires_in']
            modify_time = os.path.getmtime(cache_file)
            # Keep 60 seconds buffer
            if (modify_time + expires_in - 60) > time.time():
                # Cached token hasn't expired
                return result, True
            else:
                # Token has expired
                return None, False
    return None, False


def save_to_cache(cred):
    cred = json.dumps(cred)
    with open(os.path.expanduser(_TOKEN_CACHE_FILE), 'w') as f:
        f.write(cred)


def get_access_token():
    '''Get access token'''
    token, is_cache_available = load_from_cache()
    if is_cache_available:
        return token
    ctx = load_context()
    auth0_domain = os.environ.get("AUTH_DOMAIN")
    if auth0_domain is None:
        auth0_domain = ctx.get('domain')

    non_interactive_client_id = os.environ.get("AUTH_CLIENT_ID")
    if non_interactive_client_id is None:
        non_interactive_client_id = ctx.get('client_id')

    non_interactive_client_secret = os.environ.get("AUTH_CLIENT_SECRET")
    if non_interactive_client_secret is None:
        non_interactive_client_secret = ctx.get('client_secret')

    auth_endpoint = os.environ.get("AUTH_ENDPOINT")
    if auth_endpoint is None:
        auth_endpoint = ctx.get('endpoint')

    if auth0_domain is None or non_interactive_client_id is None or non_interactive_client_secret is None or auth_endpoint is None:
        raise NoAuthContextException()
    get_token = GetToken(auth0_domain)
    cred = get_token.client_credentials(non_interactive_client_id,
                                        non_interactive_client_secret, auth_endpoint)
    save_to_cache(cred)
    return cred


@click.command(name="get-token")
def get_token():
    click.echo(get_access_token())



import json

import yaml
from kfp.components._components import load_component_from_text

from kaistack.auth import token
from kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api import \
    PipelineComponentServiceApi
from kaistack.clients.openapi_clients.pipelinecomponents.api_client import ApiClient
from kaistack.clients.openapi_clients.pipelinecomponents.configuration import Configuration
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_pipeline_component import \
    CodegenPipelineComponent
from kaistack.components.exceptions import MissingTemplateException

KFP_COMPONENT_SPEC_ANNOTATION = "pipelines.kubeflow.org/component_spec"


def create_from_template(spec: str):
    c = CodegenPipelineComponent()
    wf = yaml.safe_load(spec)
    if 'spec' in wf and 'templates' in wf['spec']:
        templates = wf['spec']['templates']
        if len(templates) > 0:
            template = templates[0]
            c.image = template['container']['image']
            if 'metadata' in template and \
                    'annotations' in template['metadata'] and \
                    KFP_COMPONENT_SPEC_ANNOTATION in template['metadata']['annotations']:
                annotation_val = template['metadata']['annotations'][KFP_COMPONENT_SPEC_ANNOTATION]
                kfp_pipeline_spec = json.loads(annotation_val)
                c.name = kfp_pipeline_spec['name']
                c.description = kfp_pipeline_spec.get('description')
            else:
                c.name = template.get('name')
        else:
            raise MissingTemplateException
    return c


class ComponentStore:
    def __init__(self, service=None, api_base=None):
        if service is None and api_base is None:
            # In cluster
            self.configuration = Configuration("http://kaistackapiserver:8888")
            self.ApiClient = ApiClient(self.configuration, header_name="x-user", header_value="anonymous")
            self.componentApi = PipelineComponentServiceApi(self.ApiClient)
        elif service.startswith("http://localhost"):
            self.configuration = Configuration(api_base)
            self.ApiClient = ApiClient(self.configuration)
            self.componentApi = PipelineComponentServiceApi(self.ApiClient)
        else:
            self.access_token = token.get_access_token()
            self.configuration = Configuration(api_base, api_key=self.access_token['access_token'],
                                               api_key_prefix="Bearer")
            self.ApiClient = ApiClient(self.configuration, header_name="Authorization",
                                       header_value="Bearer {0}".format(self.access_token['access_token']))
            self.componentApi = PipelineComponentServiceApi(self.ApiClient)

    def list_components(self):
        return self.componentApi.list_components().components

    def create_component(self, spec: str, name: str = None):
        c = create_from_template(spec)
        if name is not None:
            c.name = name
        c.spec = spec
        return self.componentApi.create_component(c)

    def update_component(self, spec: str, name: str = None):
        c = create_from_template(spec)
        if name is not None:
            c.name = name
        c.spec = spec
        return self.componentApi.update_component(c)

    def get_component(self, id: str):
        ret = self.componentApi.get_component(id)
        if ret is not None:
            return ret.component
        return None

    def get_component_by_name(self, name: str):
        ret = self.componentApi.get_component_by_name(name)
        if ret is not None:
            return ret.component
        return None

    def get_component_by_name_and_version(self, name: str, version: str):
        ret = self.componentApi.get_component_by_name(name, version=version)
        if ret is not None:
            return ret.component
        return None

    def component_op(self, name: str, version: str = None):
        if version is None:
            c = self.get_component_by_name(name)
        else:
            c = self.get_component_by_name_and_version(name, version)
        return load_component_from_text(c.spec)

    def close(self):
        self.ApiClient.close()



import click
from kaistack.config.context import get_context, set_context
from kaistack.auth.token import get_token
from kaistack.tools.component_importer import upload_component

@click.group()
def cli():
    pass


cli.add_command(get_context)
cli.add_command(set_context)
cli.add_command(get_token)
cli.add_command(upload_component)

def main():
    cli()



import os
import logging
from kaistack.metadata.workflow_service import WorkflowService

_INITIALIZED_ = False

_POD_NAME = ''
_POD_NAME_ENV = 'KFP_POD_NAME'
_PIPELINE_RUN_ID = ''
_PIPELINE_RUN_ID_ENV = 'PIPELINE_RUN_ID'
_WORKFLOW_NAME = ''
_WORKFLOW_NAME_ENV = 'ARGO_WORKFLOW_NAME'
_PIPELINE_TEMPLATE_NAME = ''
_PIPELINE_TEMPLATE_NAME_ENV = 'PIPELINE_TEMPLATE_NAME'
_WorkFlow_Service = None
_CURRENT_RUN = None


def check_and_get_env(name):
    if name not in os.environ:
        logging.error("Cannot find environment variable {}", name)
        return ''
    else:
        return os.environ[name]


def init():
    global _INITIALIZED_
    global _PIPELINE_RUN_ID
    global _POD_NAME
    global _WORKFLOW_NAME
    global _PIPELINE_TEMPLATE_NAME
    global _WorkFlow_Service
    global _CURRENT_RUN

    # Initialize from the environment
    _PIPELINE_RUN_ID = check_and_get_env(_PIPELINE_RUN_ID_ENV)
    _POD_NAME = check_and_get_env(_POD_NAME_ENV)
    _WORKFLOW_NAME = check_and_get_env(_WORKFLOW_NAME_ENV)
    _PIPELINE_TEMPLATE_NAME = check_and_get_env(_PIPELINE_TEMPLATE_NAME_ENV)
    if "KAISTACKSEVER_URL" in os.environ:
        _WorkFlow_Service = WorkflowService(os.environ["KAISTACKSEVER_URL"])
    else:
        _WorkFlow_Service = WorkflowService()

    _CURRENT_RUN = _WorkFlow_Service.get_run_by_name("{}.{}".format(_WORKFLOW_NAME, _PIPELINE_TEMPLATE_NAME))
    _INITIALIZED_ = True


def ensure_init():
    global _INITIALIZED_
    if _INITIALIZED_:
        return
    init()


def get_run_id():
    global _CURRENT_RUN
    return _CURRENT_RUN.run_id


def get_pipeline_run_id():
    global _PIPELINE_RUN_ID
    return _PIPELINE_RUN_ID


def workflowservice():
    global _WorkFlow_Service
    return _WorkFlow_Service



# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.pipelinecomponents.configuration import Configuration


class CodegenPipelineComponent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'image': 'str',
        'creator': 'str',
        'version': 'str',
        'help_link': 'str',
        'spec': 'str',
        'sha256': 'str',
        'created_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'image': 'image',
        'creator': 'creator',
        'version': 'version',
        'help_link': 'helpLink',
        'spec': 'spec',
        'sha256': 'sha256',
        'created_time': 'createdTime'
    }

    def __init__(self, id=None, name=None, description=None, image=None, creator=None, version=None, help_link=None, spec=None, sha256=None, created_time=None, local_vars_configuration=None):  # noqa: E501
        """CodegenPipelineComponent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._image = None
        self._creator = None
        self._version = None
        self._help_link = None
        self._spec = None
        self._sha256 = None
        self._created_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if image is not None:
            self.image = image
        if creator is not None:
            self.creator = creator
        if version is not None:
            self.version = version
        if help_link is not None:
            self.help_link = help_link
        if spec is not None:
            self.spec = spec
        if sha256 is not None:
            self.sha256 = sha256
        if created_time is not None:
            self.created_time = created_time

    @property
    def id(self):
        """Gets the id of this CodegenPipelineComponent.  # noqa: E501


        :return: The id of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CodegenPipelineComponent.


        :param id: The id of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this CodegenPipelineComponent.  # noqa: E501


        :return: The name of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CodegenPipelineComponent.


        :param name: The name of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this CodegenPipelineComponent.  # noqa: E501


        :return: The description of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CodegenPipelineComponent.


        :param description: The description of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def image(self):
        """Gets the image of this CodegenPipelineComponent.  # noqa: E501


        :return: The image of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this CodegenPipelineComponent.


        :param image: The image of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def creator(self):
        """Gets the creator of this CodegenPipelineComponent.  # noqa: E501


        :return: The creator of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this CodegenPipelineComponent.


        :param creator: The creator of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._creator = creator

    @property
    def version(self):
        """Gets the version of this CodegenPipelineComponent.  # noqa: E501


        :return: The version of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CodegenPipelineComponent.


        :param version: The version of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def help_link(self):
        """Gets the help_link of this CodegenPipelineComponent.  # noqa: E501


        :return: The help_link of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._help_link

    @help_link.setter
    def help_link(self, help_link):
        """Sets the help_link of this CodegenPipelineComponent.


        :param help_link: The help_link of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._help_link = help_link

    @property
    def spec(self):
        """Gets the spec of this CodegenPipelineComponent.  # noqa: E501


        :return: The spec of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this CodegenPipelineComponent.


        :param spec: The spec of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._spec = spec

    @property
    def sha256(self):
        """Gets the sha256 of this CodegenPipelineComponent.  # noqa: E501


        :return: The sha256 of this CodegenPipelineComponent.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this CodegenPipelineComponent.


        :param sha256: The sha256 of this CodegenPipelineComponent.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def created_time(self):
        """Gets the created_time of this CodegenPipelineComponent.  # noqa: E501


        :return: The created_time of this CodegenPipelineComponent.  # noqa: E501
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this CodegenPipelineComponent.


        :param created_time: The created_time of this CodegenPipelineComponent.  # noqa: E501
        :type: datetime
        """

        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenPipelineComponent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenPipelineComponent):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.api.cluster_service_api import ClusterServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.cluster.rest import ApiException


class TestClusterServiceApi(unittest.TestCase):
    """ClusterServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.cluster.api.cluster_service_api.ClusterServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        """
        pass


if __name__ == '__main__':
    unittest.main()



from json import JSONEncoder

from kaistack.auth import token
from kaistack.clients.openapi_clients.workflow.configuration import Configuration
from kaistack.clients.openapi_clients.workflow.api_client import ApiClient
from kaistack.clients.openapi_clients.workflow.models import CodegenRun
from kaistack.clients.openapi_clients.workflow.api.workflow_service_api import WorkflowServiceApi


class CodegenMetricEncoder(JSONEncoder):
    def default(self, o):
        return {'runId': o.run_id,
                'pipelineRunId': o.pipeline_run_id,
                'name': o.name,
                'value': o.value}


class CodegenParamEncoder(JSONEncoder):
    def default(self, o):
        return {'runId': o.run_id,
                'pipelineRunId': o.pipeline_run_id,
                'name': o.name,
                'value': o.value}


class CodegenArtifactMetaEncoder(JSONEncoder):
    def default(self, o):
        return {'runId': o.run_id,
                'name': o.name,
                'type': o.type,
                'properties': o.properties}


_codeMetricEncoder = CodegenMetricEncoder()
_codeParamEncoder = CodegenParamEncoder()


class WorkflowService:
    def __init__(self, api_base=None):
        if api_base is None:
            # In cluster
            self.configuration = Configuration("http://kaistackapiserver:8888")
            self.ApiClient = ApiClient(self.configuration, header_name="x-user", header_value="anonymous")
            self.workflowApi = WorkflowServiceApi(self.ApiClient)
        elif api_base.startswith("http://localhost"):
            self.configuration = Configuration(api_base)
            self.ApiClient = ApiClient(self.configuration)
            self.workflowApi = WorkflowServiceApi(self.ApiClient)
        else:
            self.access_token = token.get_access_token()
            self.configuration = Configuration(api_base, api_key=self.access_token['access_token'],
                                               api_key_prefix="Bearer")
            self.ApiClient = ApiClient(self.configuration, header_name="Authorization",
                                       header_value="Bearer {0}".format(self.access_token['access_token']))
            self.workflowApi = WorkflowServiceApi(self.ApiClient)

    def get_run_by_name(self, name):
        response = self.workflowApi.get_run_by_name(name)
        return response.run

    def create_run(self, name):
        run = CodegenRun()
        run.name = name
        response = self.workflowApi.create_run(run)
        return response.run

    def log_metrics(self, metrics):
        response = self.workflowApi.log_metrics(_codeMetricEncoder.encode(metrics))
        return response.num_of_writes

    def log_params(self, params):
        response = self.workflowApi.log_params(_codeParamEncoder.encode(params))
        return response.num_of_writes

    def log_artifact_meta(self, meta):
        response = self.workflowApi.log_artifact_meta(meta)
        return response.artifact



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.configuration import Configuration


class CodegenArtifact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_at': 'datetime',
        'uri': 'str',
        'run_id': 'str',
        'pipeline_run_id': 'str',
        'experiment_name': 'str',
        'node': 'str',
        'name': 'str',
        'type': 'str',
        'path': 'str',
        'properties': 'dict(str, str)'
    }

    attribute_map = {
        'id': 'id',
        'created_at': 'createdAt',
        'uri': 'uri',
        'run_id': 'runId',
        'pipeline_run_id': 'pipelineRunId',
        'experiment_name': 'experimentName',
        'node': 'node',
        'name': 'name',
        'type': 'type',
        'path': 'path',
        'properties': 'properties'
    }

    def __init__(self, id=None, created_at=None, uri=None, run_id=None, pipeline_run_id=None, experiment_name=None, node=None, name=None, type=None, path=None, properties=None, local_vars_configuration=None):  # noqa: E501
        """CodegenArtifact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_at = None
        self._uri = None
        self._run_id = None
        self._pipeline_run_id = None
        self._experiment_name = None
        self._node = None
        self._name = None
        self._type = None
        self._path = None
        self._properties = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if created_at is not None:
            self.created_at = created_at
        if uri is not None:
            self.uri = uri
        if run_id is not None:
            self.run_id = run_id
        if pipeline_run_id is not None:
            self.pipeline_run_id = pipeline_run_id
        if experiment_name is not None:
            self.experiment_name = experiment_name
        if node is not None:
            self.node = node
        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if path is not None:
            self.path = path
        if properties is not None:
            self.properties = properties

    @property
    def id(self):
        """Gets the id of this CodegenArtifact.  # noqa: E501


        :return: The id of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CodegenArtifact.


        :param id: The id of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def created_at(self):
        """Gets the created_at of this CodegenArtifact.  # noqa: E501


        :return: The created_at of this CodegenArtifact.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this CodegenArtifact.


        :param created_at: The created_at of this CodegenArtifact.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def uri(self):
        """Gets the uri of this CodegenArtifact.  # noqa: E501


        :return: The uri of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this CodegenArtifact.


        :param uri: The uri of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def run_id(self):
        """Gets the run_id of this CodegenArtifact.  # noqa: E501


        :return: The run_id of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this CodegenArtifact.


        :param run_id: The run_id of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def pipeline_run_id(self):
        """Gets the pipeline_run_id of this CodegenArtifact.  # noqa: E501


        :return: The pipeline_run_id of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_run_id

    @pipeline_run_id.setter
    def pipeline_run_id(self, pipeline_run_id):
        """Sets the pipeline_run_id of this CodegenArtifact.


        :param pipeline_run_id: The pipeline_run_id of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._pipeline_run_id = pipeline_run_id

    @property
    def experiment_name(self):
        """Gets the experiment_name of this CodegenArtifact.  # noqa: E501


        :return: The experiment_name of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._experiment_name

    @experiment_name.setter
    def experiment_name(self, experiment_name):
        """Sets the experiment_name of this CodegenArtifact.


        :param experiment_name: The experiment_name of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._experiment_name = experiment_name

    @property
    def node(self):
        """Gets the node of this CodegenArtifact.  # noqa: E501


        :return: The node of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this CodegenArtifact.


        :param node: The node of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def name(self):
        """Gets the name of this CodegenArtifact.  # noqa: E501


        :return: The name of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CodegenArtifact.


        :param name: The name of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this CodegenArtifact.  # noqa: E501


        :return: The type of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CodegenArtifact.


        :param type: The type of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def path(self):
        """Gets the path of this CodegenArtifact.  # noqa: E501


        :return: The path of this CodegenArtifact.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this CodegenArtifact.


        :param path: The path of this CodegenArtifact.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def properties(self):
        """Gets the properties of this CodegenArtifact.  # noqa: E501


        :return: The properties of this CodegenArtifact.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CodegenArtifact.


        :param properties: The properties of this CodegenArtifact.  # noqa: E501
        :type: dict(str, str)
        """

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenArtifact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenArtifact):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from kaistack.clients.openapi_clients.workflow.api.workflow_service_api import WorkflowServiceApi

# import ApiClient
from kaistack.clients.openapi_clients.workflow.api_client import ApiClient
from kaistack.clients.openapi_clients.workflow.configuration import Configuration
from kaistack.clients.openapi_clients.workflow.exceptions import OpenApiException
from kaistack.clients.openapi_clients.workflow.exceptions import ApiTypeError
from kaistack.clients.openapi_clients.workflow.exceptions import ApiValueError
from kaistack.clients.openapi_clients.workflow.exceptions import ApiKeyError
from kaistack.clients.openapi_clients.workflow.exceptions import ApiException
# import models into sdk package
from kaistack.clients.openapi_clients.workflow.models.codegen_argo_workflow import CodegenArgoWorkflow
from kaistack.clients.openapi_clients.workflow.models.codegen_artifact import CodegenArtifact
from kaistack.clients.openapi_clients.workflow.models.codegen_artifact_meta import CodegenArtifactMeta
from kaistack.clients.openapi_clients.workflow.models.codegen_create_run_response import CodegenCreateRunResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_all_models_latest_version_response import CodegenGetAllModelsLatestVersionResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_argo_workflow_response import CodegenGetArgoWorkflowResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_artifact_with_properties_response import CodegenGetArtifactWithPropertiesResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_artifacts_response import CodegenGetArtifactsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_experiment_runs_response import CodegenGetExperimentRunsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_filter import CodegenGetFilter
from kaistack.clients.openapi_clients.workflow.models.codegen_get_metrics_response import CodegenGetMetricsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_model_all_versions_response import CodegenGetModelAllVersionsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_params_response import CodegenGetParamsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_pipeline_experiment_name_response import CodegenGetPipelineExperimentNameResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_pipeline_run_id_response import CodegenGetPipelineRunIdResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_pipeline_runs_response import CodegenGetPipelineRunsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_run_by_name_response import CodegenGetRunByNameResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_get_run_response import CodegenGetRunResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_log_artifact_meta_response import CodegenLogArtifactMetaResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_log_metrics_response import CodegenLogMetricsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_log_params_response import CodegenLogParamsResponse
from kaistack.clients.openapi_clients.workflow.models.codegen_metric import CodegenMetric
from kaistack.clients.openapi_clients.workflow.models.codegen_model import CodegenModel
from kaistack.clients.openapi_clients.workflow.models.codegen_param import CodegenParam
from kaistack.clients.openapi_clients.workflow.models.codegen_pipeline_run_detail import CodegenPipelineRunDetail
from kaistack.clients.openapi_clients.workflow.models.codegen_run import CodegenRun
from kaistack.clients.openapi_clients.workflow.models.codegen_workflow_action_response import CodegenWorkflowActionResponse




# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.workflow
from kaistack.clients.openapi_clients.workflow.api.workflow_service_api import WorkflowServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.workflow.rest import ApiException


class TestWorkflowServiceApi(unittest.TestCase):
    """WorkflowServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.workflow.api.workflow_service_api.WorkflowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_run(self):
        """Test case for create_run

        """
        pass

    def test_get_argo_workflow(self):
        """Test case for get_argo_workflow

        """
        pass

    def test_get_artifact_with_properties(self):
        """Test case for get_artifact_with_properties

        """
        pass

    def test_get_artifacts_with_filter(self):
        """Test case for get_artifacts_with_filter

        """
        pass

    def test_get_metrics(self):
        """Test case for get_metrics

        """
        pass

    def test_get_params(self):
        """Test case for get_params

        """
        pass

    def test_get_pipeline_experiment_name(self):
        """Test case for get_pipeline_experiment_name

        """
        pass

    def test_get_pipeline_run_id(self):
        """Test case for get_pipeline_run_id

        """
        pass

    def test_get_pipeline_runs(self):
        """Test case for get_pipeline_runs

        """
        pass

    def test_get_run(self):
        """Test case for get_run

        """
        pass

    def test_get_run_by_name(self):
        """Test case for get_run_by_name

        """
        pass

    def test_log_artifact_meta(self):
        """Test case for log_artifact_meta

        """
        pass

    def test_log_metrics(self):
        """Test case for log_metrics

        """
        pass

    def test_log_params(self):
        """Test case for log_params

        """
        pass


if __name__ == '__main__':
    unittest.main()
